# PTIC

PTIC tool for texts classification, uses following statistical model:

* point-wise mutual information for word and a class
* tf-idf (term frequency-inverse document frequency) for word in a text

## Installation

```bash
pip install --requirement https://raw.githubusercontent.com/sysbio-vo/ptic/main/requirements.txt
pip install ptic
```
